@@ -1,4 +1,5 @@
 import inspect
+import json
 import re
 from pathlib import Path
 from typing import Dict, List
@@ -8,6 +9,7 @@ from flask import Flask
 from flask import request as flask_request
 from flask_json import JsonError, as_json
 from loguru import logger
+from requests_toolbelt import MultipartDecoder
 
 from .model import AudioRequest, StructuredTextRequest, TextRequest
 from .utils.docker import COPY_FOLDER, DOCKERFILE, ENTRYPOINT
@@ -46,13 +48,30 @@ class FlaskService:
         """
         Main request processing logic - accepts a JSON request and returns a JSON response.
         """
-        data = flask_request.get_json()
-        if data.get("type") == "text":
+        logger.info("Process request")
+        if "application/json" in flask_request.content_type:
+            data = flask_request.get_json()
+        elif "multipart/form-data" in flask_request.content_type:
+            decoder = MultipartDecoder(flask_request.get_data(), flask_request.content_type)
+            data = {}
+            for part in decoder.parts:
+                headers = {k.decode(): v.decode() for k, v in part.headers.items()}
+                if "application/json" in headers["Content-Type"]:
+                    for k, v in json.loads(part.content.decode()).items():
+                        data[k] = v
+                elif "audio" in headers["Content-Type"]:
+                    data["content"] = part.content
+                else:
+                    raise ValueError("Unknown Content-Type in multipart request")
+        else:
+            raise ValueError()
+
+        if data.get("type") == "audio":
+            request = AudioRequest(**data)
+        elif data.get("type") == "text":
             request = TextRequest(**data)
         elif data.get("type") == "structuredText":
             request = StructuredTextRequest(**data)
-        elif data.get("type") == "audio":
-            request = AudioRequest(**data)
         else:
             self.invalid_request_error()
         logger.info(f"Call with the input: {request}")
