@@ -417,13 +417,45 @@ class Service(Entity, NeedAuthentication):
             print(f"with request:\n\t{request}\n")
 
         headers = {"Authorization": f"Bearer {self.authentication.access_token}"}
-        if sync_mode:
-            return self._call_sync(request=request, headers=headers, timeout=timeout, output_func=output_func)
+        post_kwargs = {}
+        if (
+            isinstance(request, AudioRequest) and self.id == 0
+        ):  # self.id == 0 corresponds to a service initialized from a docker image
+            files = {
+                "request": (
+                    None,
+                    json.dumps(
+                        {
+                            "type": "audio",
+                            "format": request.format,
+                            "sampleRate": request.sample_rate,
+                            "features": request.features,
+                            "annotations": request.annotations,
+                        }
+                    ),
+                    "application/json",
+                ),
+                "content": (None, request.content, "audio/x-wav" if request.format == "linear16" else "audio/mpeg"),
+            }
+            data = None
+            post_kwargs = {"files": files}
+        elif isinstance(request, AudioRequest):
+            data = request.content
+            headers["Content-Type"] = "audio/x-wav" if request.format == "linear16" else "audio/mpeg"
+        elif isinstance(request, TextRequest) or isinstance(request, StructuredTextRequest):
+            data = json.dumps(request.dict())
+            headers["Content-Type"] = "application/json"
         else:
-            return self._call_async(request=request, headers=headers, timeout=timeout, output_func=output_func)
+            raise ValueError(f"Request type {type(request)} not recognized.")
+        if sync_mode:
+            return self._call_sync(data=data, headers=headers, timeout=timeout, output_func=output_func, **post_kwargs)
+        else:
+            return self._call_async(
+                data=data, headers=headers, timeout=timeout, output_func=output_func, **post_kwargs
+            )
 
     @catch_requests_error
-    def _call_sync(self, request: Request, headers: Dict, timeout: int, output_func: Callable) -> Union[Dict, str]:
+    def _call_sync(self, data: str, headers: Dict, timeout: int, output_func: Callable, **kwargs) -> Union[Dict, str]:
         """
         Method used by __call__ to call a service synchronously.
 
@@ -438,20 +470,14 @@ class Service(Entity, NeedAuthentication):
         Returns:
             Union[Dict, str]: service response in JSON format or as a string if output_func returns a string.
         """
-        if isinstance(request, AudioRequest):
-            data = request.content
-            headers["Content-Type"] = "audio/x-wav" if request.format == "linear16" else "audio/mpeg"
-        elif isinstance(request, TextRequest) or isinstance(request, StructuredTextRequest):
-            data = json.dumps(request.dict())
-            headers["Content-Type"] = "application/json"
-        else:
-            raise ValueError(f"Request type {type(request)} not recognized.")
-        response = requests.post(self.elg_execution_location_sync, headers=headers, data=data, timeout=timeout)
+        response = requests.post(
+            self.elg_execution_location_sync, headers=headers, data=data, timeout=timeout, **kwargs
+        )
         ensure_response_ok(response)
         return output_func(get_response(response.json()))
 
     @catch_requests_error
-    def _call_async(self, request: Request, headers: Dict, timeout: int, output_func: Callable) -> Union[Dict, str]:
+    def _call_async(self, data: str, headers: Dict, timeout: int, output_func: Callable, **kwargs) -> Union[Dict, str]:
         """
         Method used by __call__ to call a service asynchronously.
 
@@ -466,15 +492,7 @@ class Service(Entity, NeedAuthentication):
         Returns:
             Union[Dict, str]: service response in JSON format or as a string if output_func returns a string.
         """
-        if isinstance(request, AudioRequest):
-            data = request.content
-            headers["Content-Type"] = "audio/x-wav" if request.format == "linear16" else "audio/mpeg"
-        elif isinstance(request, TextRequest) or isinstance(request, StructuredTextRequest):
-            data = json.dumps(request.dict())
-            headers["Content-Type"] = "application/json"
-        else:
-            raise ValueError(f"Request type {type(request)} not recognized.")
-        response = requests.post(self.elg_execution_location, headers=headers, data=data, timeout=timeout)
+        response = requests.post(self.elg_execution_location, headers=headers, data=data, timeout=timeout, **kwargs)
         ensure_response_ok(response)
         response = response.json()["response"]
         assert response["type"] == "stored"
